#!/usr/bin/env python3

import pytest
import pandas as pd
from io import StringIO
import experiment_design
import os

test_output_path = os.path.dirname(os.path.abspath(__file__)) + \
                '/../output/design/'

DESIGN_STRING = r"""sample_id\ttag_align\txcor\treplicate
A_1\tA_1.tagAlign.gz\tA\t1
A_2\tA_2.tagAlign.gz\tA\t2
B_1\tB_1.tagAlign.gz\tB\t1
B_2\tB_2.tagAlign.gz\tB\t2
"""


@pytest.fixture
def design_tag():
    design_file = StringIO(DESIGN_STRING)
    design_df = pd.read_csv(design_file, sep="\t")
    return design_df



@pytest.mark.integration
def test_experiment_design_single_end():
    design_file = os.path.join(test_output_path, 'ENCSR265ZXX.tsv')
    assert os.path.exists(design_file)
    design_df = pd.read_csv(design_file, sep="\t")
    assert design_df.shape[0] == 3


@pytest.mark.integration
def test_experiment_design_paired_end():
    # Do the same thing for paired end data
    pass
