#!/usr/bin/env python3

import pytest
import os

test_data_path = os.path.dirname(os.path.abspath(__file__)) + \
                '/../../test_data/'
test_output_path = os.path.dirname(os.path.abspath(__file__)) + \
                '/../output/trimReads/'



@pytest.mark.pairedend_mouse
def test_trim_reads_pairedend_mouse():
    raw_fastq1 = test_data_path + 'ENCFF913PMS.fastq.gz'
    trimmed_fastq1 = test_output_path + 'ENCLB122XDP/ENCLB122XDP_R1_val_1.fq.gz'

    raw_fastq2 = test_data_path + 'ENCFF999SZR.fastq.gz'
    trimmed_fastq2 = test_output_path + 'ENCLB749GLW/ENCLB749GLW_R2_val_2.fq.gz'

    assert os.path.getsize(raw_fastq1) != os.path.getsize(trimmed_fastq1)
    assert os.path.getsize(trimmed_fastq1) == 934738906

    assert os.path.getsize(raw_fastq2) != os.path.getsize(trimmed_fastq2)
    assert os.path.getsize(trimmed_fastq2) == 1297020342

    trimmed_fastq_report1 = test_output_path + \
                             'ENCLB122XDP/ENCLB122XDP_R1.fastq.gz_trimming_report.txt'
    assert 'Trimming mode: paired-end' in open(trimmed_fastq_report1).readlines()[4]

    trimmed_fastq_report2 = test_output_path + \
                             'ENCLB749GLW/ENCLB749GLW_R1.fastq.gz_trimming_report.txt'
    assert 'Trimming mode: paired-end' in open(trimmed_fastq_report2).readlines()[4]


@pytest.mark.singleend_human
def test_trim_reads_singleend_human():
    raw_fastq = test_data_path + 'ENCFF115PAE.fastq.gz'
    trimmed_fastq = test_output_path + 'ENCLB170KFO/ENCLB170KFO_R1_trimmed.fq.gz'

    assert os.path.getsize(raw_fastq) != os.path.getsize(trimmed_fastq)
    assert os.path.getsize(trimmed_fastq) == 2171147098

    trimmed_fastq_report = test_output_path + \
                            'ENCLB969KTX/ENCLB969KTX_R1.fastq.gz_trimming_report.txt'
    assert 'Trimming mode: single-end' in open(trimmed_fastq_report).readlines()[4]


